# Generated by roxygen2: do not edit by hand

export("%>%")
export(copydata)
export(rem_pg_nums)
export(rs_setup)
export(ru_addbignvar)
export(ru_addpage)
export(ru_addsupp)
export(ru_align)
export(ru_contents)
export(ru_data2codelist)
export(ru_datacompare)
export(ru_datetime)
export(ru_denorm)
export(ru_expvarlist)
export(ru_fillcodedcode)
export(ru_fillna)
export(ru_freq)
export(ru_getdata)
export(ru_groupbyvars)
export(ru_labels)
export(ru_libname)
export(ru_list)
export(ru_load_library)
export(ru_setdata)
export(ru_stackvar)
export(ru_sumstats)
export(ru_width_rtf)
import(dplyr)
import(haven)
import(r2rtf)
import(stringr)
import(tidyr)
importFrom(Hmisc,label)
importFrom(magrittr,"%>%")
importFrom(rlang,":=")
