---
title: "Proc-Contents"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Proc-Contents}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

## Vignette Build Datetime

```{r built}
message(paste0('Datetime: ',Sys.Date(),':',Sys.time()))
```

```{r setup}
library(repfun)
```

## Generate a Proc Contents style report of a data frame in R

```{r contents2file}
#fnam <- paste0(base::tempdir(),"/test-ru_contents.txt")
#sink(fnam)
ret <- repfun::ru_contents(airquality)
#sink()
```

## Display the result

```{r contents2out}
#cat(readLines(fnam), sep = '\n')
base::cat("\n", ret$s_data_info)
base::cat(ret$fmt_str)
base::cat("\n", ret$s_var_info_1)
```


