---
title: "SAS-Type-Variable-Expansion"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{SAS-Type-Variable-Expansion}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

## Vignette Build Datetime

```{r built}
message(paste0('Datetime: ',Sys.Date(),':',Sys.time()))
```

## Load Libraries

```{r setup, message=FALSE}
library(repfun)
```

## Example 1: SAS Type Expansion of Variable List 

```{r type1}
df <- data.frame(tt_ac01=c('1','2','3'),
                 tt_ac02=c('a','b','b'),
                 tt_ac03=c('10','11','12'))
repfun::ru_expvarlist(df, varsin="tt_ac:")
```

## Example 2: SAS Type Expansion of Variable List 

```{r type2}
df <- data.frame(tt_ac01=c('1','2','3'),
                 tt_ac03=c('10','11','12'))
repfun::ru_expvarlist(df, varsin="tt_ac:")
```

## Example 3: SAS Type Expansion of Variable List 

```{r type3}
df <- data.frame(tt_ac01=c('1','2','3'),
                 tt_ac03=c('10','11','12'))
repfun::ru_expvarlist(df, varsin="tt_ac01-tt_ac10")
```
